#!/bin/bash

# Check are you root?
echo "*****************************************************"
echo "   ShenZhen KTSerial TouchScreen Install"
echo "*****************************************************"
echo ""

whoami | egrep "^root$" >/dev/null

if [ $? -ne 0 ]; then
  echo "Warning: You are not root!"
  echo "         Installation Failed!"
  exit
fi

echo "Show some information and check them!"

# Check what kind of the X Server is!
if [ -f /var/log/Xorg.0.log ]; then
  PATH_XServerConfig=$(egrep "Using config file" /var/log/Xorg.0.log|cut -d" " -f5|cut -d\" -f2)
  echo "X Window Config is in $PATH_XServerConfig"
  PATH_XServerModule=/usr/lib/xorg/modules
  echo "X Window Module Path is in $PATH_XServerModule"
else
  echo "Warning: Don't know where is your X Server config file."
  echo "         Installation Failed!"
  exit
fi

# I want to know where is your path!
echo $0 | egrep ^/ >/dev/null
if [ $? == 0 ]; then
  INSTALL_PATH=${0%/*}
else
  INSTALL_PATH=${PWD}/${0%/*}
fi

# the file is main file that I want to change!
TARGET_FILE=$PATH_XServerConfig

# Start to install
mkdir /etc/ktsrl

cp -f "$INSTALL_PATH"/keetouch_drv.so "$PATH_XServerModule"/input

echo "Add touch configuration into $PATH_XServerConfig."
sed -i '/ServerLayout/a\\tInputDevice\t"kts" "SendCoreEvents"' $PATH_XServerConfig

filelines=`cat $PATH_XServerConfig | wc -l`
sed -i ''${filelines}'a\### Touch Configuration Begin ###\
Section "InputDevice"\
    Identifier  "kts"\
    Driver 		"keetouch"\
    Option 		"Device" "/dev/ttyS0"\
    Option 		"DeviceName"	 "KTSRL"\
    Option 		"SendCoreEvents" 	"yes"\
    Option 		"Drag"	 "1"\
EndSection \
### Touch Configuration End ###' $PATH_XServerConfig

cp -f "$INSTALL_PATH"/KTcalibrateS /etc/ktsrl
cp -f "$INSTALL_PATH"/uninstall.sh /etc/ktsrl
cp -f "$INSTALL_PATH"/readme.txt /etc/ktsrl
cp -f "$INSTALL_PATH"/KT3PointS.cal /etc

"$INSTALL_PATH"/KTcalibrateS

echo
echo "Touch Driver has Installed."
echo
echo "Calibration tools are in the directory /etc/ktsrl"
echo "you can copy them to your desktop."

choice=" "
while [ "$choice" != "y" ]; do
echo
echo -n "Do you want to Reboot now? (y/n):"
read choice
echo
case $choice in
      y|Y) echo 'Rebooting...'
           reboot
           echo;;
      n|N) echo 'It is recommaned to reboot after driver installed'
           echo
           break;;
      *) ;;
esac
done
